% Auto-generated chapter 34 for nasai
% Hadiths in this chapter: 42

\hadithdefcmd{nasai}{3720}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ سَمِعْتُ طَاوُسًا، يُحَدِّثُ عَنْ زَيْدِ بْنِ ثَابِتٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَى هِيَ لِلْوَارِثِ ‏"‏ ‏.‏\hadithno{3720}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zaid bin Thabit that the Prophet said:"'Umra (a gift given for life) belongs to the heir}}
\hadithdefcmd{nasai}{3721}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، قَالَ سَمِعْتُ طَاوُسًا، يُحَدِّثُ عَنْ حُجْرٍ الْمَدَرِيِّ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَى لِلْوَارِثِ ‏"‏ ‏.‏\hadithno{3721}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zaid bin Thabit that the Messenger of Allah said:"'Umra (a gift given for life) belongs to the heir}}
\hadithdefcmd{nasai}{3722}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ سُفْيَانَ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، عَنْ حُجْرٍ الْمَدَرِيِّ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى بِالْعُمْرَى لِلْوَارِثِ ‏.‏\hadithno{3722}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zaid bin Thabit that the Prophet ruled that 'Umra (a gift given for life) belongs to the heir}}
\hadithdefcmd{nasai}{3722p2}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ سُفْيَانَ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، عَنْ حُجْرٍ الْمَدَرِيِّ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى بِالْعُمْرَى لِلْوَارِثِ ‏.‏\hadithno{3722.2}\hadithtrans{It was narrated from Zaid bin Thabit that the Prophet ruled that 'Umra (a gift given for life) belongs to the heir}}
\hadithdefcmd{nasai}{3723}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ بْنِ يَزِيدَ بْنِ إِبْرَاهِيمَ، قَالَ أَخْبَرَنِي أَبِي أَنَّهُ، عَرَضَ عَلَىَّ مَعْقِلٌ عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ حُجْرٍ الْمَدَرِيِّ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْمَرَ شَيْئًا فَهُوَ لِمُعْمَرِهِ مَحْيَاهُ وَمَمَاتَهُ وَلاَ تَرْقُبُوا فَمَنْ أَرْقَبَ شَيْئًا فَهُوَ لِسَبِيلِهِ ‏"‏ ‏.‏\hadithno{3723}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Zaid bin Thabit said:The Messenger of Allah said: "Whoever gives a life-long gift, it belongs to the one to whom he gave it, both during his life and after his death. And do not give things on the basis of Ruqba, for whoever is given something on the basis of Ruqba, it becomes part of his estate}}
\hadithdefcmd{nasai}{3724}{أَخْبَرَنِي زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ، قَالَ أَنْبَأَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، قَالَ حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ الْحَجُورِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَى جَائِزَةٌ ‏"‏ ‏.‏\hadithno{3724}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah bin 'Abbas that the Prophet said:"'Umra is permissible}}
\hadithdefcmd{nasai}{3725}{أَخْبَرَنَا هَارُونُ بْنُ مُحَمَّدِ بْنِ بَكَّارِ بْنِ بِلاَلٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا سَعِيدٌ، - هُوَ ابْنُ بَشِيرٍ - عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْعُمْرَى جَائِزَةٌ ‏"‏ ‏.‏\hadithno{3725}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet said:"Indeed 'Umra is permissible}}
\hadithdefcmd{nasai}{3726}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ حَدَّثَنَا حِبَّانُ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، قَالَ حَدَّثَنَا مَكْحُولٌ، عَنْ طَاوُسٍ، بَتَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْعُمْرَى وَالرُّقْبَى ‏.‏\hadithno{3726}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Tawus that the Messenger of Allah made 'Umra and Ruqba binding}}
\hadithdefcmd{nasai}{3727}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا بِسْطَامُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنَا مَالِكُ بْنُ دِينَارٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَطَبَهُمْ فَقَالَ ‏ "‏ الْعُمْرَى جَائِزَةٌ ‏"‏ ‏.‏\hadithno{3727}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Malik bin Dinar narrated from 'Ata', from Jabir that the Messenger of Allah addressed them one day and said:"'Umra is permissible}}
\hadithdefcmd{nasai}{3728}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ أَنْبَأَنَا عُبَيْدُ اللَّهِ، عَنْ إِسْرَائِيلَ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ عَطَاءٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْعُمْرَى وَالرُّقْبَى ‏.‏ قُلْتُ وَمَا الرُّقْبَى قَالَ يَقُولُ الرَّجُلُ لِلرَّجُلِ هِيَ لَكَ حَيَاتَكَ ‏.‏ فَإِنْ فَعَلْتُمْ فَهُوَ جَائِزَةٌ ‏.‏\hadithno{3728}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdul-Karim narrated from 'Ata', who said:"The Messenger of Allah forbade 'Umra and Ruqba." I said: "What is Ruqba?" He said: "When one man says to another: 'This belongs to you for the rest of your life.' But if you do that, it is permissible}}
\hadithdefcmd{nasai}{3729}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ عَطَاءٍ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَى جَائِزَةٌ ‏"‏ ‏.‏\hadithno{3729}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Shu'bah said:"I heard Qatadah narrating from 'Ata', from Jabir that the Prophet said: 'Umra is permissible}}
\hadithdefcmd{nasai}{3730}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ أَنْبَأَنَا حِبَّانُ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أُعْطِيَ شَيْئًا حَيَاتَهُ فَهُوَ لَهُ حَيَاتَهُ وَمَوْتَهُ ‏"‏ ‏.‏\hadithno{3730}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdul-Malik bin Abi Sulaiman narrated from 'Ata' who said:"The Messenger of Allah said: 'Whoever is given something for the rest of his life, it belongs to him for as long as he lives and after he dies}}
\hadithdefcmd{nasai}{3731}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ سُفْيَانَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُرْقِبُوا وَلاَ تُعْمِرُوا فَمَنْ أُرْقِبَ أَوْ أُعْمِرَ شَيْئًا فَهُوَ لِوَرَثَتِهِ ‏"‏ ‏.‏\hadithno{3731}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Sufyan narrated from Ibn Juraij, from 'Ata', from Jabir that the Messenger of Allah said:"Do not give things on the basis of Ruqba or 'Umra. Whoever is given something on the basis of Ruqba or 'Umra, it belongs to his heirs}}
\hadithdefcmd{nasai}{3732}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، أَنْبَأَنَا حَبِيبُ بْنُ أَبِي ثَابِتٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ عُمْرَى وَلاَ رُقْبَى فَمَنْ أُعْمِرَ شَيْئًا أَوْ أُرْقِبَهُ فَهُوَ لَهُ حَيَاتَهُ وَمَمَاتَهُ ‏"‏ ‏.‏\hadithno{3732}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Juraij narrated from 'Ata':"Habib bin Abi Thabit informed us from Ibn 'Umar, that the Messenger of Allah said: 'There is no 'Umra and no Ruqba. Whoever is given something on the basis of 'Umra or Ruqba, it belongs to him for the rest of his life and after he dies}}
\hadithdefcmd{nasai}{3733}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، ‏\{‏ قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، ‏\}‏ قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنِ ابْنِ عُمَرَ، وَلَمْ يَسْمَعْهُ مِنْهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ عُمْرَى وَلاَ رُقْبَى فَمَنْ أُعْمِرَ شَيْئًا أَوْ أُرْقِبَهُ فَهُوَ لَهُ حَيَاتَهُ وَمَمَاتَهُ ‏"‏ ‏.‏ قَالَ عَطَاءٌ هُوَ لِلآخَرِ ‏.‏\hadithno{3733}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Juraij said:'Ata' informed me, from Habib bin Abi Thabit, from Ibn 'Umar -and he did not hear it from him- he said: 'Allah's Messenger said: "There is no 'Umra and no Ruqba. Whoever is given something on the basis of 'Umra or Ruqba, it belongs to him for the rest of his life and after he dies."' 'Ata' said: "It belongs to the other}}
\hadithdefcmd{nasai}{3734}{أَخْبَرَنِي عَبْدَةُ بْنُ عَبْدِ الرَّحِيمِ، قَالَ أَنْبَأَنَا وَكِيعٌ، عَنْ يَزِيدَ بْنِ زِيَادِ بْنِ أَبِي الْجَعْدِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الرُّقْبَى وَقَالَ ‏ "‏ مَنْ أُرْقِبَ رُقْبَى فَهُوَ لَهُ ‏"‏ ‏.‏\hadithno{3734}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Yazid bin Ziyad bin Abi Al-Ja'd narrated from Habib bin Abi Thabit, who said:"I heard Ibn 'Umar say: 'The Messenger of Allah forbade Ruqba and said: "Whoever is given something on the basis of Ruqba, it belongs to him}}
\hadithdefcmd{nasai}{3735}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أُعْمِرَ شَيْئًا فَهُوَ لَهُ حَيَاتَهُ وَمَمَاتَهُ ‏"‏ ‏.‏\hadithno{3735}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn Juraij said:"Abu Az-Zubair informed me that he heard Jabir saying: 'The Messenger of Allah said: "Whoever is given something on the basis of 'Umra it belongs to him for the rest of his life and after he dies}}
\hadithdefcmd{nasai}{3736}{أَخْبَرَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ بْنِ صُدْرَانَ، عَنْ بِشْرِ بْنِ الْمُفَضَّلِ، قَالَ حَدَّثَنَا الْحَجَّاجُ الصَّوَّافُ، عَنْ أَبِي الزُّبَيْرِ، قَالَ حَدَّثَنَا جَابِرٌ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا مَعْشَرَ الأَنْصَارِ امْسِكُوا عَلَيْكُمْ - يَعْنِي أَمْوَالَكُمْ - لاَ تُعْمِرُوهَا فَإِنَّهُ مَنْ أَعْمَرَ شَيْئًا فَإِنَّهُ لِمَنْ أُعْمِرَهُ حَيَاتَهُ وَمَمَاتَهُ ‏"‏ ‏.‏\hadithno{3736}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Al-Hajjaj bin As-Sawwaf narrated from Abu Az-Zubair, who said:"Jabir said: 'The Messenger of Allah said: "O Ansar! Hold on to your wealth, and do not give it on the basis of 'Umra. For whoever gives something on the basis of 'Umra, it belongs to the one to whom he gave it on that basis, for the rest of his life and after he dies}}
\hadithdefcmd{nasai}{3737}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ هِشَامٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ امْسِكُوا عَلَيْكُمْ أَمْوَالَكُمْ وَلاَ تُعْمِرُوهَا فَمَنْ أُعْمِرَ شَيْئًا حَيَاتَهُ فَهُوَ لَهُ حَيَاتَهُ وَبَعْدَ مَوْتِهِ ‏"‏ ‏.‏\hadithno{3737}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Hisham narrated from Abu Az-Zubair, from Jabir, that the Messenger of Allah said:"Hold on to your wealth and do not give it on the basis of 'Umra. For whoever is given something on the basis of 'Umra for the rest of his life, it belongs to him for the rest of his life and after his death}}
\hadithdefcmd{nasai}{3738}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الرُّقْبَى لِمَنْ أُرْقِبَهَا ‏"‏ ‏.‏\hadithno{3738}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Khalid narrated from Dawud bin Abi Hind, from Abu Az-Zubair, from Jabir, who said:"The Messenger of Allah said: 'Ruqba belongs to the one to whom it is given}}
\hadithdefcmd{nasai}{3739}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنْ دَاوُدَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعُمْرَى جَائِزَةٌ لأَهْلِهَا وَالرُّقْبَى جَائِزَةٌ لأَهْلِهَا ‏"‏ ‏.‏\hadithno{3739}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Hushaim narrated from Dawud, from Abu Az-Zubair, from Jabir, who said:"The Messenger of Allah said: 'Umra is permissible for the one to whom it is given, and Ruqba is permissible for the one to whom it is given}}
\hadithdefcmd{nasai}{3740}{أَخْبَرَنَا مَحْمُودُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا عُمَرُ، عَنِ الأَوْزَاعِيِّ، حَدَّثَنَا ابْنُ شِهَابٍ، قَالَ وَأَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، أَنْبَأَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أُعْمِرَ عُمْرَى فَهِيَ لَهُ وَلِعَقِبِهِ يَرِثُهَا مَنْ يَرِثُهُ مِنْ عَقِبِهِ ‏"‏ ‏.‏\hadithno{3740}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Al-Awza'i narrated from Az-Zuhri, from 'Urwah, from Jabir, who said:"The Messenger of Allah said: 'Whoever is given something on the basis of 'Umra, it belongs to him and to his descendants, and is inherited by those who inherit from him}}
\hadithdefcmd{nasai}{3741}{أَخْبَرَنَا عِيسَى بْنُ مُسَاوِرٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنَا أَبُو عَمْرٍو، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعُمْرَى لِمَنْ أُعْمِرَهَا هِيَ لَهُ وَلِعَقِبِهِ يَرِثُهَا مَنْ يَرِثُهُ مِنْ عَقِبِهِ ‏"‏ ‏.‏\hadithno{3741}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{(A different chain) from Abu 'Amr, from Ibn Shihab, from Abu Salamah, from Jabir, who said:"The Messenger of Allah said: 'Umra (a lifelong gift) belongs to the one to whom it was given; it belongs to him and to his heirs, and is inherited by those among his descendants who inherit from him}}
\hadithdefcmd{nasai}{3742}{أَخْبَرَنَا مُحَمَّدُ بْنُ هَاشِمٍ الْبَعْلَبَكِّيُّ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، وَأَبِي، سَلَمَةَ عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعُمْرَى لِمَنْ أُعْمِرَهَا هِيَ لَهُ وَلِعَقِبِهِ يَرِثُهَا مَنْ يَرِثُهُ مِنْ عَقِبِهِ ‏"‏ ‏.‏\hadithno{3742}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{(A different chain) from Al-Awza'i, from Az-Zuhri, from 'Urwah and Abu Salamah, from Jabir, who said:"The Messenger of Allah said: 'Umra (a lifelong gift) belongs to the one to whom it was given; it belongs to him and to his descendants, and is inherited by those who inherit from him}}
\hadithdefcmd{nasai}{3743}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنَا عَمْرُو بْنُ أَبِي سَلَمَةَ الدِّمَشْقِيُّ، عَنْ أَبِي عُمَرَ الصَّنْعَانِيِّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا رَجُلٍ أَعْمَرَ رَجُلاً عُمْرَى لَهُ وَلِعَقِبِهِ فَهِيَ لَهُ وَلِمَنْ يَرِثُهُ مِنْ عَقِبِهِ مَوْرُوثَةٌ ‏"‏ ‏.‏\hadithno{3743}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Hisham bin 'Urwah, from his father, from 'Abdullah bin Az-Zubair, that the Messenger of Allah said:"Any man who gives a lifelong gift to another man, it belongs to him (the recipient) and to his descendants, and to those who inherit from him}}
\hadithdefcmd{nasai}{3744}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَعْمَرَ رَجُلاً عُمْرَى لَهُ وَلِعَقِبِهِ فَقَدْ قَطَعَ قَوْلُهُ حَقَّهُ وَهِيَ لِمَنْ أُعْمِرَ وَلِعَقِبِهِ ‏"‏ ‏.‏\hadithno{3744}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Al-Laith narrated from Ibn Shihab, from Abu Salamah bin 'Abdur-Rahman, from Jabir, who said:"I heard the Messenger of Allah say: 'Whoever gives a life-long gift to a man, it belongs to him and to his heirs; his words (when he gave the gift) put an end to his rights over it, and it belongs to the one to whom it was given on the basis of 'Umra, and to his heirs}}
\hadithdefcmd{nasai}{3745}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا رَجُلٍ أُعْمِرَ عُمْرَى لَهُ وَلِعَقِبِهِ فَإِنَّهَا لِلَّذِي يُعْطَاهَا لاَ تَرْجِعُ إِلَى الَّذِي أَعْطَاهَا لأَنَّهُ أَعْطَى عَطَاءً وَقَعَتْ فِيهِ الْمَوَارِيثُ ‏"‏ ‏.‏\hadithno{3745}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Malik narrated from Ibn Shihab, from Abu Salamah, from Jabir that the Messenger of Allah said:"Any man who is given a gift on the basis of 'Umra, it belongs to him and to his descendants. It belongs to the one to whom he gave it, and it cannot be taken back by the one who gave it, because he has given a gift, and it comes to the heirs of the one to whom it was given}}
\hadithdefcmd{nasai}{3746}{أَخْبَرَنَا عِمْرَانُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ حَدَّثَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ جَابِرًا، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى أَنَّهُ مَنْ أَعْمَرَ رَجُلاً عُمْرَى لَهُ وَلِعَقِبِهِ فَإِنَّهَا لِلَّذِي أُعْمِرَهَا يَرِثُهَا مِنْ صَاحِبِهَا الَّذِي أَعْطَاهَا مَا وَقَعَ مِنْ مَوَارِيثِ اللَّهِ وَحَقِّهِ ‏.‏\hadithno{3746}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Shua'ib narrated from Az-Zuhri, who said:"Abu Salamah bin 'Abdur-Rahman narrated to me, that Jabir told him: 'The Messenger of Allah ruled that whoever gives a lifelong gift to a man, it belongs to him and to his heirs. It belongs to the one to whom it was given, on the basis of 'Umra. It will be inherited from its recipient according to Allah's (injunctions on) inheritance and its rights}}
\hadithdefcmd{nasai}{3747}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنِ ابْنِ أَبِي فُدَيْكٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِيمَنْ أُعْمِرَ عُمْرَى لَهُ وَلِعَقِبِهِ فَهِيَ لَهُ بَتْلَةٌ لاَ يَجُوزُ لِلْمُعْطِي مِنْهَا شَرْطٌ وَلاَ ثُنْيَا ‏.‏ قَالَ أَبُو سَلَمَةَ لأَنَّهُ أَعْطَى عَطَاءً وَقَعَتْ فِيهِ الْمَوَارِيثُ فَقَطَعَتِ الْمَوَارِيثُ شَرْطَهُ ‏.‏\hadithno{3747}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Abi Dhi'b narrated from Ibn Shihab, from Abu Salamah, from Jabir, that the Messenger of Allah ruled -concerning a person who has been given a lifelong gift ('Umra)- that it belongs to him and to his descendants:"It is undoubtedly his, and it is not permissible for the giver to stipulate any conditions or exceptions." Abu Salamah said: "Because he gave it as a gift and thus, it is subject to the same ruling as the estate, and the condition (that it will revert to the giver on the death of recipient) has become invalid}}
\hadithdefcmd{nasai}{3748}{أَخْبَرَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ سَيْفٍ قَالَ حَدَّثَنَا يَعْقُوبُ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ أَبَا سَلَمَةَ، أَخْبَرَهُ عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا رَجُلٍ أَعْمَرَ رَجُلاً عُمْرَى لَهُ وَلِعَقِبِهِ قَالَ قَدْ أَعْطَيْتُكَهَا وَعَقِبَكَ مَا بَقِيَ مِنْكُمْ أَحَدٌ فَإِنَّهَا لِمَنْ أُعْطِيَهَا وَإِنَّهَا لاَ تَرْجِعُ إِلَى صَاحِبِهَا مِنْ أَجْلِ أَنَّهُ أَعْطَاهَا عَطَاءً وَقَعَتْ فِيهِ الْمَوَارِيثُ ‏"‏ ‏.‏\hadithno{3748}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Salih narrated from Ibn Shihab, that Abu Salamah informed him from Jabir, that the Messenger of Allah said:"Any man who gives a lifelong gift to another man, it belongs to him (the recipient) and his descendants. He said: 'I have given it to you and to your descendants so long as any of you are still alive.' So it belongs to the one to whom it was given, and it cannot revert to the first owner, since he has given it as a gift, and as such, it becomes subject to the same ruling as the estate}}
\hadithdefcmd{nasai}{3749}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا سَعِيدٌ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى بِالْعُمْرَى أَنْ يَهَبَ الرَّجُلُ لِلرَّجُلِ وَلِعَقِبِهِ الْهِبَةَ وَيَسْتَثْنِي إِنْ حَدَثَ بِكَ حَدَثٌ وَبِعَقِبِكَ فَهُوَ إِلَىَّ وَإِلَى عَقِبِي إِنَّهَا لِمَنْ أُعْطِيَهَا وَلِعَقِبِهِ ‏.‏\hadithno{3749}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Yazid bin Abi Habib narrated from Ibn Shihab, from Abu Salamah, from Jabir, that the Messenger of Allah ruled concerning 'Umra -when a man gives a gift to another man, and his descendants, but stipulates that if something happens to you and your descendants, then it will belong to me and my descendants- "It belongs to the one to whom it was given, and to his descendants}}
\hadithdefcmd{nasai}{3750}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ، قَالَ سَمِعْتُ جَابِرًا، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعُمْرَى لِمَنْ وُهِبَتْ لَهُ ‏"‏ ‏.‏\hadithno{3750}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Hisham said:"Yahya bin Abi Kathir narrated to us, he said: 'Abu Salamah bin 'Abdur-Rahman narrated to me, he said: "I heard Jabir say: 'The Messenger of Allah said: "A lifelong gift belongs to the one to whom it was given}}
\hadithdefcmd{nasai}{3751}{أَخْبَرَنَا يَحْيَى بْنُ دُرُسْتَ، قَالَ حَدَّثَنَا أَبُو إِسْمَاعِيلَ، قَالَ حَدَّثَنَا يَحْيَى، أَنَّ أَبَا سَلَمَةَ، حَدَّثَهُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنْ نَبِيِّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَى لِمَنْ وُهِبَتْ لَهُ ‏"‏ ‏.‏\hadithno{3751}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Isma'il said:"Yahya narrated to us that Abu Salamah narrated to him, from Jabir bin 'Abdullah, from the Prophet of Allah who said: 'A lifelong gift belongs to the one to whom it was given}}
\hadithdefcmd{nasai}{3752}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ مُحَمَّدٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ عُمْرَى فَمَنْ أُعْمِرَ شَيْئًا فَهُوَ لَهُ ‏"‏ ‏.‏\hadithno{3752}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Isma'il narrated from Muhammad, from Abu Salamah, from Abu Hurairah, that the Messenger of Allah said:"There is no lifelong gift. Whoever is given something as a lifelong gift, it belongs to him}}
\hadithdefcmd{nasai}{3753}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عِيسَى، وَعَبْدَةُ بْنُ سُلَيْمَانَ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أُعْمِرَ شَيْئًا فَهُوَ لَهُ ‏"‏ ‏.‏\hadithno{3753}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Muhammad bin 'Amr said:"Abu Salamah narrated to us, from Abu Hurairah that the Messenger of Allah said: 'Whoever is given something as a lifelong gift, it belongs to him}}
\hadithdefcmd{nasai}{3754}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَى جَائِزَةٌ ‏"‏ ‏.‏\hadithno{3754}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Bashir bin Nahik narrated from Abu Hurairah that the Prophet said:"A lifelong gift ('Umra) is permissible}}
\hadithdefcmd{nasai}{3755}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، قَالَ سَأَلَنِي سُلَيْمَانُ بْنُ هِشَامٍ عَنِ الْعُمْرَى، فَقُلْتُ حَدَّثَ مُحَمَّدُ بْنُ سِيرِينَ، عَنْ شُرَيْحٍ، قَالَ قَضَى نَبِيُّ اللَّهِ صلى الله عليه وسلم أَنَّ الْعُمْرَى جَائِزَةٌ ‏.‏ قَالَ قَتَادَةُ وَقُلْتُ حَدَّثَنِي النَّضْرُ بْنُ أَنَسٍ عَنْ بَشِيرِ بْنِ نَهِيكٍ عَنْ أَبِي هُرَيْرَةَ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الْعُمْرَى جَائِزَةٌ ‏"‏ ‏.‏ قَالَ قَتَادَةُ وَقُلْتُ كَانَ الْحَسَنُ يَقُولُ الْعُمْرَى جَائِزَةٌ ‏.‏ قَالَ قَتَادَةُ فَقَالَ الزُّهْرِيُّ إِنَّمَا الْعُمْرَى إِذَا أُعْمِرَ وَعَقِبَهُ مِنْ بَعْدِهِ فَإِذَا لَمْ يَجْعَلْ عَقِبَهُ مِنْ بَعْدِهِ كَانَ لِلَّذِي يَجْعَلُ شَرْطُهُ ‏.‏ قَالَ قَتَادَةُ فَسُئِلَ عَطَاءُ بْنُ أَبِي رَبَاحٍ فَقَالَ حَدَّثَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الْعُمْرَى جَائِزَةٌ ‏"‏ ‏.‏ قَالَ قَتَادَةُ فَقَالَ الزُّهْرِيُّ كَانَ الْخُلَفَاءُ لاَ يَقْضُونَ بِهَذَا ‏.‏ قَالَ عَطَاءٌ قَضَى بِهَا عَبْدُ الْمَلِكِ بْنُ مَرْوَانَ ‏.‏\hadithno{3755}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Qatadah said:"Sulaiman bin Hisham asked me about a lifelong gift. I said: 'Muhammad bin Sirin narrated that Shuraih said: "The Prophet of Allah ruled that a lifelong gift is permissible."'" Qatadah said: "I said: 'And An-Nadr bin Anas narrated to me, from Bashir bin Nahik, from Abu Hurairah, that the Prophet of Allah said: "A lifelong gift is permissible."'" Qatadah said: "I said: 'Al-Hasan used to say: "A lifelong gift is permissible."'" Qatadah said: "Az-Zuhri said: 'A lifelong gift is when it is stipulated that it is for the one to whom it is given and his descendants, but if his descendants were not mentioned then the condition is valid (and it reverts to the one who gave it).'" Qatadah said: "So 'Ata' bin Abi Rabah was asked, and he said: 'Jabir bin Abdullah narrated to me that Allah's Messenger said: "Umra is permissible."'" Qatadah said: "Az-Zuhri said: 'The Caliphs (Khulafa') did not rule according to this.'" 'Ata' said: "Abdul-Malik bin Marwan ruled according to this}}
\hadithdefcmd{nasai}{3756}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا حَبَّانُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، ح وَأَخْبَرَنِي إِبْرَاهِيمُ بْنُ يُونُسَ بْنِ مُحَمَّدٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ دَاوُدَ، - وَهُوَ ابْنُ أَبِي هِنْدٍ - وَحَبِيبٍ الْمُعَلِّمِ عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَجُوزُ لاِمْرَأَةٍ هِبَةٌ فِي مَالِهَا إِذَا مَلَكَ زَوْجُهَا عِصْمَتَهَا ‏"‏ ‏.‏ اللَّفْظُ لِمُحَمَّدٍ ‏.‏\hadithno{3756}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather, that the Messenger of Allah said:"It is not permissible for a woman to give a gift from her wealth, once her husband has marital authority over her." This is the wording of (one of the narrators) Muhammad}}
\hadithdefcmd{nasai}{3757}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، أَنَّ أَبَاهُ، حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، ح وَأَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ لَمَّا فَتَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَكَّةَ قَامَ خَطِيبًا فَقَالَ فِي خُطْبَتِهِ ‏ "‏ لاَ يَجُوزُ لاِمْرَأَةٍ عَطِيَّةٌ إِلاَّ بِإِذْنِ زَوْجِهَا ‏"‏ ‏.‏\hadithno{3757}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said:"When the Messenger of Allah conquered Makkah, he stood up to address (the people) and said in his Khutbah: 'It is not permissible for a woman to give (a gift) except with her husband's permission}}
\hadithdefcmd{nasai}{3758}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، قَالَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ يَحْيَى بْنِ هَانِئٍ، عَنْ أَبِي حُذَيْفَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ مُحَمَّدِ بْنِ بَشِيرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَلْقَمَةَ الثَّقَفِيِّ، قَالَ قَدِمَ وَفْدُ ثَقِيفٍ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَعَهُمْ هَدِيَّةٌ فَقَالَ ‏ "‏ أَهَدِيَّةٌ أَمْ صَدَقَةٌ فَإِنْ كَانَتْ هَدِيَّةً فَإِنَّمَا يُبْتَغَى بِهَا وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَضَاءُ الْحَاجَةِ وَإِنْ كَانَتْ صَدَقَةً فَإِنَّمَا يُبْتَغَى بِهَا وَجْهُ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏ قَالُوا لاَ بَلْ هَدِيَّةٌ ‏.‏ فَقَبِلَهَا مِنْهُمْ وَقَعَدَ مَعَهُمْ يُسَائِلُهُمْ وَيُسَائِلُونَهُ حَتَّى صَلَّى الظُّهْرَ مَعَ الْعَصْرِ ‏.‏\hadithno{3758}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdur-Rahman bin 'Alqamah Ath-Thaqafi said:"The delegation of Thaqif came to the Messenger of Allah, bringing a gift with them. He said: 'Is it a gift or charity?' If it was a gift it would be for the sake of the Messenger of Allah and to have their needs met, and if it was charity then it would be in the cause of Allah. They said: 'It is a gift.' So he accepted it from them, and sat with them, and they asked questions, until he prayed Zuhr with 'Asr}}
\hadithdefcmd{nasai}{3759}{أَخْبَرَنَا أَبُو عَاصِمٍ، خُشَيْشُ بْنُ أَصْرَمَ قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَقَدْ هَمَمْتُ أَنْ لاَ أَقْبَلَ هَدِيَّةً إِلاَّ مِنْ قُرَشِيٍّ أَوْ أَنْصَارِيٍّ أَوْ ثَقَفِيٍّ أَوْ دَوْسِيٍّ ‏"‏ ‏.‏\hadithno{3759}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"I was thinking of not accepting gifts except from a Quraishi, an Ansari, a Thaqafi or a Dawsi}}
\hadithdefcmd{nasai}{3760}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِلَحْمٍ فَقَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ فَقِيلَ تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ ‏.‏ فَقَالَ ‏"‏ هُوَ لَهَا صَدَقَةٌ وَلَنَا هَدِيَّةٌ ‏"‏ ‏.‏\hadithno{3760}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas that some meat was brought to the Messenger of Allah and he said:"What is this?" It was said: "It was given in charity to Barirah." He said: "It is charity for her and a gift for us}}
